import type { RouteLocationRaw, Router } from 'vue-router/auto'
import { PageEnum, REDIRECT_NAME } from '~/constants'

export type PathAsPageEnum<T> = T extends { path: string } ? T & { path: PageEnum } : T
export type RouteLocationRawEx = PathAsPageEnum<RouteLocationRaw>

function handleError(e: Error) {
  console.error(e)
}

export function useGo(_router?: Router) {
  const { push, replace } = _router || useRouter()
  function go(opt: RouteLocationRawEx = PageEnum.BASE_HOME, isReplace = false) {
    if (!opt) {
      return
    }
    isReplace ? replace(opt).catch(handleError) : push(opt).catch(handleError)
  }
  return go
}

export function useRedo(_router?: Router) {
  const { push, currentRoute } = _router || useRouter()
  const { query, params = {}, name, fullPath } = unref(currentRoute)
  function redo(): Promise<boolean> {
    return new Promise((resolve) => {
      if (name === REDIRECT_NAME) {
        resolve(false)
        return
      }
      if (name && Object.keys(params).length > 0) {
        // @ts-expect-error tstype
        params._redirect_type = 'name'
        // @ts-expect-error tstype
        params.path = String(name)
      }
      else {
        // @ts-expect-error tstype
        params._redirect_type = 'path'
        // @ts-expect-error tstype
        params.path = fullPath
      }
      // @ts-expect-error tstype
      push({ name: REDIRECT_NAME, params, query }).then(() => resolve(true))
    })
  }
  return redo
}
