import { storeToRefs } from 'pinia'
import { filterTree, getAllParentPath, hideFilter } from '~/utils'

export function useMenu() {
  const routeStore = useRouteStore()
  const { initMenu, menuListRef } = storeToRefs(routeStore)

  const getMenuList = async () => {
    if (!unref(initMenu)) {
      await routeStore.buildMenu()
    }
    const menuList = filterTree(unref(menuListRef), hideFilter)
    return menuList
  }

  const getCurrentParentPath = async (currentPath: string) => {
    const menus = await getMenuList()
    const allParentPath = await getAllParentPath(menus, currentPath)
    return allParentPath?.[0]
  }

  const getShallowMenus = async () => {
    const menus = await getMenuList()
    const shallowMenuList = menus.map(item => ({
      ...item,
      children: undefined,
    }))
    // if (isRoleMode()) {
    //   const routes = router.getRoutes()
    //   return shallowMenuList.filter(basicFilter(routes))
    // }
    return shallowMenuList
  }

  const getChildrenMenus = async (parentPath: string) => {
    const menus = await getMenuList()
    const parent = menus.find(item => item.path === parentPath)
    if (!parent || !parent.children || !!parent?.meta?.hideChildrenInMenu) {
      return [] as Menu[]
    }
    // if (isRoleMode()) {
    //   const routes = router.getRoutes()
    //   return filterTree(parent.children, basicFilter(routes))
    // }
    return parent.children
  }

  return {
    getMenuList,
    getShallowMenus,
    getChildrenMenus,
    getCurrentParentPath,
  }
}
