import { acceptHMRUpdate, defineStore } from 'pinia'

import { ThemeEnum } from '~/constants'

interface ThemeStoreState {
  themeConfig: ThemeColorConfig
  theme: ThemeEnum
  sidebar: ThemeEnum
  header: ThemeEnum
}

const initState: ThemeStoreState = {
  themeConfig: {
    primaryColor: '#2a64d4',
    infoColor: '#2080F0',
    successColor: '#52c41a',
    warningColor: '#faad14',
    errorColor: '#D03050',
    textBaseColor: '#000000',
    bgBaseColor: '#ffffff',
  },
  theme: ThemeEnum.LIGHT,
  sidebar: ThemeEnum.DARK,
  header: ThemeEnum.LIGHT,
}

export const useThemeStore = defineStore('APP_THEME', () => {
  const state = $ref<ThemeStoreState>(Object.assign({}, initState))

  function setThemeConfig(config: Partial<ThemeColorConfig>) {
    state.themeConfig = { ...state.themeConfig, ...config }
  }

  function setSidebarTheme(value: ThemeEnum) {
    state.sidebar = value
  }

  function setHeaderTheme(value: ThemeEnum) {
    state.header = value
  }

  return {
    ...toRefs(state),
    setThemeConfig,
    setSidebarTheme,
    setHeaderTheme,
  }
}, {
  persist: {
    paths: Object.keys(initState),
  },
})

if (import.meta.hot)
  import.meta.hot.accept(acceptHMRUpdate(useThemeStore as any, import.meta.hot))
