import type {
  AlignEnum,
  ContentLayoutEnum,
  MenuModeEnum,
  MixSidebarTriggerEnum,
  NavBarModeEnum,
  PermissionModeEnum,
  PlacementEnum,
  RouterTransitionEnum,
  SessionTimeoutProcessingEnum,
  SettingButtonPositionEnum,
  ThemeEnum,
  TopMenuAlignEnum,
  TriggerEnum,
} from '~/constants'

declare global {
  interface DefineAppConfigOptions {
    // Navigation bar mode
    navBarMode: NavBarModeEnum
    // Theme
    theme: ThemeEnum
    // Theme color
    themeColor: string
    // Whether to show the theme switch button
    showThemeModeToggle: boolean
    // pageLayout whether to enable keep-alive
    openKeepAlive: boolean
    // Whether to open back to top
    useOpenBackTop: boolean
    // Is it possible to embed iframe pages
    canEmbedIFramePage: boolean
    // Whether to delete unclosed messages and notify when switching the interface
    closeMessageOnSwitch: boolean
    closeMixSidebarOnChange: boolean
    // Whether to cancel the http request that has been sent but not responded when switching the interface.
    removeAllHttpPending: boolean
    // // Storage location of permission related information
    // permissionCacheType: CacheTypeEnum
    // Permission mode
    permissionMode: PermissionModeEnum
    // Configure where the button is displayed
    settingButtonPosition: SettingButtonPositionEnum[]
    // Configuration setting drawer open
    openSettingDrawer: boolean
    // Session timeout processing
    sessionTimeoutProcessing: SessionTimeoutProcessingEnum
    // Website gray mode, open for possible mourning dates
    grayMode: boolean
    // Whether to turn on the color weak mode
    colorWeak: boolean
    // Lock screen time
    lockTime: number
    // Whether to show the lock screen
    useLockPage: boolean
    sidebar: SidebarConfigOptions
    menu: MenuConfigOptions
    header: HeaderConfigOptions
    logo: LogoConfigOptions
    tabTar: TabTarConfigOptions
    content: ContentConfigOptions
    footer: FooterConfigOptions
    transition: TransitionConfigOptions
  }

  // 边栏配置
  interface SidebarConfigOptions {
    theme: ThemeEnum
    show: boolean
    visible: boolean
    fixed: boolean
    collapsed: boolean
    width: number
    trigger: TriggerEnum
    readonly mixSidebarWidth: number
    readonly collapsedWidth: number
  }

  // 菜单栏配置
  interface MenuConfigOptions {
    show: boolean
    canDrag: boolean
    split: boolean
    mode: MenuModeEnum
    accordion: boolean
    collapsedShowTitle: boolean
    mixSideTrigger: MixSidebarTriggerEnum
    mixSideFixed: boolean
    topMenuAlign: AlignEnum

    subMenuWidth: number
    dropdownPlacement: PlacementEnum
  }

  // 顶栏配置
  interface HeaderConfigOptions {
    theme: ThemeEnum
    show: boolean
    visible: boolean
    fixed: boolean
    showFullScreen: boolean
    showDoc: boolean
    showNotice: boolean
    showSearch: boolean
    showLocalePicker: boolean
    showSetting: boolean
    readonly height: number
    // Show breadcrumbs
    showBreadCrumb: boolean
    // Show breadcrumb icon
    showBreadCrumbIcon: boolean
  }

  // Logo配置
  interface LogoConfigOptions {
    show: boolean
    visible: boolean
    showTitle: boolean
  }

  // 内容配置
  interface ContentConfigOptions {
    fullScreen: boolean
    mode: ContentLayoutEnum
  }

  // 底栏配置
  interface FooterConfigOptions {
    show: boolean
    visible: boolean
    readonly height: number
  }

  // 动画配置
  interface TransitionConfigOptions {
    //  Whether to open the page switching animation
    enable: boolean
    // Route basic switching animation
    basicTransition: RouterTransitionEnum
    // Whether to open page switching loading
    openPageLoading: boolean
    // Whether to open the top progress bar
    openNProgress: boolean
  }

  interface MenuStore {
    show: boolean
    canDrag: boolean
    split: boolean
    mode: MenuModeEnum
    // 手风琴模式
    accordion: boolean
    collapsedShowTitle: boolean
    mixSideTrigger: MixSidebarTriggerEnum
    mixSideFixed: boolean
    topMenuAlign: TopMenuAlignEnum
    dropdownPlacement: string
    subMenuWidth: number
  }

  // 语言配置
  interface LocaleConfig {
    // current locale
    locale: string
    // default locale
    fallback: string
    // available locales
    availableLocales: string[]
  }
}
