import { isClient } from '@vueuse/core'

function resizeHandler(entries: ResizeObserverEntry[]) {
  for (const entry of entries) {
    // @ts-expect-error nop
    const listeners = entry.target.__resizeListeners__ || []
    if (listeners.length) {
      listeners.forEach((fn: any) => {
        fn()
      })
    }
  }
}

export function addResizeListener(element: any, fn: (...args: unknown[]) => unknown) {
  if (!isClient || !element)
    return
  if (!element.__resizeListeners__) {
    element.__resizeListeners__ = []
    element.__ro__ = new ResizeObserver(resizeHandler)
    element.__ro__.observe(element)
  }
  element.__resizeListeners__.push(fn)
}

export function removeResizeListener(element: any, fn: (...args: unknown[]) => unknown) {
  if (!element || !element.__resizeListeners__)
    return
  element.__resizeListeners__.splice(element.__resizeListeners__.indexOf(fn), 1)
  if (!element.__resizeListeners__.length) {
    element.__ro__?.disconnect()
  }
}

export function triggerWindowResize() {
  const event = new Event('resize', { cancelable: true, bubbles: true })
  window.dispatchEvent(event)
//   (event as any,
//   ).eventType = 'message'
//   window.dispatchEvent(event)
}
