declare type ErrorMessageMode = 'none' | 'modal' | 'message' | undefined;
declare type SuccessMessageMode = ErrorMessageMode;

declare interface RequestOptions {
  // Splicing request parameters to url
  joinParamsToUrl?: boolean;
  // Format request parameter time
  formatDate?: boolean;
  // Whether to process the request result | 是否直接处理返回消息，直接返回data
  isTransformResponse?: boolean;
  // Whether to return native response headers | 是否返回原生响应头
  // For example: use this attribute when you need to get the response headers
  isReturnNativeResponse?: boolean;
  // Whether to join url
  joinPrefix?: boolean;
  // Interface address, use the default apiUrl if you leave it blank
  apiUrl?: string;
  // 请求拼接路径
  urlPrefix?: string;
  // Error message prompt type
  errorMessageMode?: ErrorMessageMode;
  // Success message prompt type
  successMessageMode?: SuccessMessageMode;
  // Whether to add a timestamp
  joinTime?: boolean;
  ignoreCancelToken?: boolean;
  // Whether to send token in header
  withToken?: boolean;
}

// Api返回数据结构
declare interface ApiResult<T = any> {
    code: number;
    type: 'success' | 'error' | 'warning';
    msg: string;
    data: T;
  }

  // multipart/form-data: upload file
declare interface UploadFileParams {
    // Other parameters
    data?: Recordable;
    // File parameter interface field name
    name?: string;
    // file name
    file: File | Blob;
    // file name
    filename?: string;
    [key: string]: any;
  }